window.Gleam.initSearch([{"doc":"remote_data","title":"remote_data","content":"# remote_data for Gleam\n\nThis package is inspired on the Elm package [RemoteData](https://package.elm-lang.org/packages/krisajenkins/remotedata/latest/).\n\n[![Package Version](https://img.shields.io/hexpm/v/remote_data)](https://hex.pm/packages/remote_data)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/remote_data/)\n\n## Installation\n\n```sh\ngleam add remote_data\n```\n\n## Usage\n\nThis example shows how to use the `remote_data` package in a [lustre](https://hexdocs.pm/lustre/index.html) application.\n\nFirst you wrap the data you want to fetch in a `RemoteData` type:\n\n```gleam\nimport remote_data.{type RemoteData} as rd\nimport lustre\nimport lustre/element\nimport lustre/element/html\nimport lustre_http.{type HttpError}\n\n// MODEL -----------------------------------------------------------------------\n\ntype Model {\n  Model(quote: RemoteData(Quote, HttpError))\n}\n\ntype Quote {\n  Quote(author: String, content: String)\n}\n```\n\nInitialize the model with `rd.NotAsked`:\n```gleam\nfn init(_) -&gt; #(Model, Effect(Msg)) {\n  #(Model(quote: rd.NotAsked), effect.none())\n}\n\n```\n\nWhen you want to fetch data, you can use the `rd.Loading` constructor to indicate that the data is being fetched.\nWhen the data is fetched, you can use the `rd.from_result` to convert the `Result` to a `RemoteData` type:\n\n```gleam\npub opaque type Msg {\n  UserClickedRefresh\n  ApiUpdatedQuote(Result(Quote, HttpError))\n}\n\nfn update(model: Model, msg: Msg) -&gt; #(Model, Effect(Msg)) {\n  case msg {\n    UserClickedRefresh -&gt; #(Model(quote: rd.Loading), get_quote())\n    ApiUpdatedQuote(quote) -&gt; #(Model(quote: rd.from_result(quote)), effect.none())\n  }\n}\n\nfn get_quote() -&gt; Effect(Msg) {\n  let url = &quot;https://api.quotable.io/random&quot;\n  let decoder =\n    dynamic.decode2(\n      Quote,\n      dynamic.field(&quot;author&quot;, dynamic.string),\n      dynamic.field(&quot;content&quot;, dynamic.string),\n    )\n\n  lustre_http.get(url, lustre_http.expect_json(decoder, ApiUpdatedQuote))\n}\n\n```\n\nFinally, you can pattern match on the `RemoteData` type to display the data in the view:\n\n```gleam\nfn view_quote(quote: RemoteData(Quote, HttpError)) -&gt; Element(msg) {\n  case quote {\n    rd.Success(quote) -&gt;\n      html.div([], [\n        element.text(quote.author &lt;&gt; &quot; once said...&quot;),\n        html.p([attribute.style([#(&quot;font-style&quot;, &quot;italic&quot;)])], [\n          element.text(quote.content),\n        ]),\n      ])\n    rd.NotAsked -&gt; html.p([], [element.text(&quot;Click the button to get a quote!&quot;)])\n    rd.Loading -&gt; html.p([], [element.text(&quot;Fetching quote...&quot;)])\n    rd.Failure(_) -&gt; html.p([], [element.text(&quot;Failed to fetch quote!&quot;)])\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/remote_data&gt;.\n","url":"index.html"},{"doc":"remote_data","title":"RemoteData","content":"pub type RemoteData(a, error) {\n  NotAsked\n  Loading\n  Failure(error)\n  Success(a)\n}\n\nNotAsked\n\n\nLoading\n\n\nFailure(error)\n\n\nSuccess(a)\n\n\nSynonyms:\nremote_data.RemoteData\nremote_data RemoteData","url":"remote_data.html#RemoteData"},{"doc":"remote_data","title":"from_list","content":"pub fn from_list(\n  data_list: List(RemoteData(a, b)),\n) -&gt; RemoteData(List(a), b)\n Convert a list of RemoteData to a RemoteData of a list\n ## Examples\n \n from_list([Success(1), Success(2)])\n // -&gt; Success([1, 2])\n \n\n \n from_list([Success(1), Failure(&quot;error&quot;)])\n // -&gt; Failure(&quot;error&quot;)\n \nSynonyms:\nremote_data.from_list\nremote_data from_list","url":"remote_data.html#from_list"},{"doc":"remote_data","title":"from_option","content":"pub fn from_option(\n  option: Option(a),\n  or error: b,\n) -&gt; RemoteData(a, b)\n Convert an Option to a RemoteData\n ## Examples\n \n from_option(Some(1), or: &quot;error&quot;)\n // -&gt; Success(1)\n \n\n \n from_option(None, or: &quot;error&quot;)\n // -&gt; Failure(&quot;error&quot;)\n \nSynonyms:\nremote_data.from_option\nremote_data from_option","url":"remote_data.html#from_option"},{"doc":"remote_data","title":"from_result","content":"pub fn from_result(result: Result(a, b)) -&gt; RemoteData(a, b)\n Convert a Result to a RemoteData\n ## Examples\n \n from_result(Ok(1))\n // -&gt; Success(1)\n \n\n \n from_result(Error(&quot;error&quot;))\n // -&gt; Failure(&quot;error&quot;)\n \nSynonyms:\nremote_data.from_result\nremote_data from_result","url":"remote_data.html#from_result"},{"doc":"remote_data","title":"is_failure","content":"pub fn is_failure(data: RemoteData(a, b)) -&gt; Bool\n Check if a RemoteData is a Success\n ## Examples\n \n is_failure(Success(1))\n // -&gt; False\n \n\n \n is_failure(Failure(&quot;error&quot;))\n // -&gt; True\n \nSynonyms:\nremote_data.is_failure\nremote_data is_failure","url":"remote_data.html#is_failure"},{"doc":"remote_data","title":"is_loading","content":"pub fn is_loading(data: RemoteData(a, b)) -&gt; Bool\n Check if a RemoteData is a Success\n ## Examples\n \n is_loading(Success(1))\n // -&gt; False\n \n\n \n is_loading(Loading)\n // -&gt; True\n \nSynonyms:\nremote_data.is_loading\nremote_data is_loading","url":"remote_data.html#is_loading"},{"doc":"remote_data","title":"is_not_asked","content":"pub fn is_not_asked(data: RemoteData(a, b)) -&gt; Bool\n Check if a RemoteData is a Success\n ## Examples\n \n is_not_asked(Success(1))\n // -&gt; False\n \n\n \n is_not_asked(NotAsked)\n // -&gt; True\n \nSynonyms:\nremote_data.is_not_asked\nremote_data is_not_asked","url":"remote_data.html#is_not_asked"},{"doc":"remote_data","title":"is_success","content":"pub fn is_success(data: RemoteData(a, b)) -&gt; Bool\n Check if a RemoteData is a Success\n ## Examples\n \n is_success(Success(1))\n // -&gt; True\n \n\n \n is_success(Failure(&quot;error&quot;))\n // -&gt; False\n \nSynonyms:\nremote_data.is_success\nremote_data is_success","url":"remote_data.html#is_success"},{"doc":"remote_data","title":"map","content":"pub fn map(\n  over data: RemoteData(a, b),\n  with mapper: fn(a) -&gt; c,\n) -&gt; RemoteData(c, b)\n Map a function over the success value of a RemoteData\n\n ## Examples\n \n map(over: Success(1), with: int.to_string)\n // -&gt; Success(&quot;1&quot;)\n \n\n \n map(over: Failure(&quot;error&quot;), with: int.to_string)\n // -&gt; Failure(&quot;error&quot;)\n \nSynonyms:\nremote_data.map\nremote_data map","url":"remote_data.html#map"},{"doc":"remote_data","title":"map2","content":"pub fn map2(\n  over data1: RemoteData(a, b),\n  over2 data2: RemoteData(c, b),\n  with mapper: fn(a, c) -&gt; d,\n) -&gt; RemoteData(d, b)\n Map a function over the success value of two RemoteData values\n\n ## Examples\n \n map_2(over: Success(1), over2: Success(2), with: fn(a, b) { a + b })\n // -&gt; Success(3)\n \n\n \n map_2(over: Failure(&quot;error&quot;), over2: Success(2), with: fn(a, b) { a + b })\n // -&gt; Failure(&quot;error&quot;)\n \nSynonyms:\nremote_data.map2\nremote_data map2","url":"remote_data.html#map2"},{"doc":"remote_data","title":"map3","content":"pub fn map3(\n  over data1: RemoteData(a, b),\n  over2 data2: RemoteData(c, b),\n  over3 data3: RemoteData(d, b),\n  with mapper: fn(a, c, d) -&gt; e,\n) -&gt; RemoteData(e, b)\n The same as `map2`, but with three RemoteData values\n Check `map2` for more details\nSynonyms:\nremote_data.map3\nremote_data map3","url":"remote_data.html#map3"},{"doc":"remote_data","title":"map_error","content":"pub fn map_error(\n  over data: RemoteData(a, b),\n  with mapper: fn(b) -&gt; c,\n) -&gt; RemoteData(a, c)\n Map a function over the error value of a RemoteData\n\n ## Examples\n \n map_error(over: Success(42), with: fn(_) { &quot;error&quot; })\n // -&gt; Success(42)\n \n\n \n map_error(over: Failure(42), with: fn(_) { &quot;error&quot; })\n // -&gt; Failure(&quot;error&quot;)\n \nSynonyms:\nremote_data.map_error\nremote_data map_error","url":"remote_data.html#map_error"},{"doc":"remote_data","title":"to_option","content":"pub fn to_option(data: RemoteData(a, b)) -&gt; Option(a)\n Convert a RemoteData to an Option\n ## Examples\n \n to_option(Success(1))\n // -&gt; Some(1)\n \n\n \n to_option(Failure(&quot;error&quot;))\n // -&gt; None\n \nSynonyms:\nremote_data.to_option\nremote_data to_option","url":"remote_data.html#to_option"},{"doc":"remote_data","title":"to_result","content":"pub fn to_result(\n  data: RemoteData(a, b),\n  or error: b,\n) -&gt; Result(a, b)\n Convert a RemoteData to a Result\n If the data is NotAsked or Loading, it will be converted to an Error with the provided error\n ## Examples\n \n to_result(Success(1), or: &quot;error&quot;)\n // -&gt; Ok(1)\n \n\n \n to_result(Failure(&quot;error&quot;), or: &quot;another error&quot;)\n // -&gt; Error(&quot;error&quot;)\n \n\n \n to_result(Loading, or: &quot;another error&quot;)\n // -&gt; Error(&quot;another error&quot;)\n \nSynonyms:\nremote_data.to_result\nremote_data to_result","url":"remote_data.html#to_result"},{"doc":"remote_data","title":"try","content":"pub fn try(\n  over data: RemoteData(a, b),\n  with mapper: fn(a) -&gt; RemoteData(c, b),\n) -&gt; RemoteData(c, b)\n Chain a function that returns a RemoteData over the success value of a RemoteData\n\n ## Examples\n \n try(over: Success(1), with: fn(x) { Success(x * 2) })\n // -&gt; Success(2)\n \n\n \n try(over: Failure(&quot;error&quot;), with: fn(x) { Success(x * 2) })\n // -&gt; Failure(&quot;error&quot;)\n \n\n \n try(over: Success(1), with: fn(x) { Failure(&quot;error&quot;) })\n // -&gt; Failure(&quot;error&quot;)\n \nSynonyms:\nremote_data.try\nremote_data try","url":"remote_data.html#try"},{"doc":"remote_data","title":"unwrap","content":"pub fn unwrap(data: RemoteData(a, b), or default: a) -&gt; a\n Unwrap a RemoteData, providing a default value if the data is not Success\n ## Examples\n \n unwrap(Success(1), or: 0)\n // -&gt; 1\n \n\n \n unwrap(Failure(&quot;error&quot;), or: 0)\n // -&gt; 0\n \nSynonyms:\nremote_data.unwrap\nremote_data unwrap","url":"remote_data.html#unwrap"},{"doc":"remote_data","title":"remote_data","content":" A type that represents a remote data fetch","url":"remote_data.html"}]);